@@ -1,5 +1,7 @@
-/* Copyright (c) 1996, 1999-2004, 2007 MySQL AB
-   This file is public domain and comes with NO WARRANTY of any kind */
+/* Copyright Abandoned 1996,1999 TCX DataKonsult AB & Monty Program KB
+   & Detron HB, 1996, 1999-2004, 2007 MySQL AB.
+   This file is public domain and comes with NO WARRANTY of any kind
+*/
 
 /* Version numbers for protocol & mysqld */
 
@@ -9,11 +11,11 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MYSQL_SERVER_VERSION		"5.1.73"
-#define MYSQL_BASE_VERSION		"mysqld-5.1"
+#define MYSQL_SERVER_VERSION		"5.5.48"
+#define MYSQL_BASE_VERSION		"mysqld-5.5"
 #define MYSQL_SERVER_SUFFIX_DEF		""
 #define FRM_VER				6
-#define MYSQL_VERSION_ID		50173
+#define MYSQL_VERSION_ID		50548
 #define MYSQL_PORT			3306
 #define MYSQL_PORT_DEFAULT		0
 #define MYSQL_UNIX_ADDR			"/tmp/mysql.sock"
